package com.zfire.jiasm.syncdata.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.zfire.jiasm.syncdata.base.BaseService;
import com.zfire.jiasm.syncdata.base.WorkerCertificateInfo;
import com.zfire.jiasm.syncdata.constant.DictTypeEnum;
import com.zfire.jiasm.syncdata.constant.TaskConfigEnum;
import com.zfire.jiasm.syncdata.gree.GreeLogic;
import com.zfire.jiasm.syncdata.helper.GreeResponseHelper;
import com.zfire.jiasm.syncdata.plus.entity.*;
import com.zfire.jiasm.syncdata.plus.service.*;
import com.zfire.jiasm.syncdata.request.SignSplb;
import com.zfire.jiasm.syncdata.request.WorkUploadInfo;
import com.zfire.jiasm.syncdata.request.ZJInfo;
import com.zfire.jiasm.syncdata.response.WebsitQXLB;
import com.zfire.jiasm.syncdata.response.WorkerUploadResponse;
import com.zfire.jiasm.syncdata.service.PublicService;
import com.zfire.jiasm.syncdata.service.UploadWorkerTOGreeService;
import lombok.extern.slf4j.Slf4j;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;


@Slf4j
@Service
public class UploadWorkerTOGreeServiceImpl implements UploadWorkerTOGreeService {
    @Resource
    BaseService baseService;
    @Resource
    OutWorkerUploadService outWorkerUploadService;
    @Resource
    WorkerService workerService;
    @Resource
    WorkerBrandAccountService workerBrandAccountService;
    @Resource
    WorkerStreetService workerStreetService;
    @Resource
    WorkerCertService workerCertService;
    @Resource
    WorkerServiceCategoryDetailService workerServiceCategoryDetailService;
    @Resource
    SysDictRefService sysDictRefService;
    @Resource
    SysDictService sysDictService;
    @Resource
    GreeLogic greeLogic;
    @Resource
    ItfTblWangdianPositionDownloadService itfTblWangdianPositionDownloadService;
    @Resource
    PublicService publicService;
    @Resource
    WebsitWorkerService websitWorkerService;





    @Override
    public void procesUploadWorker() throws Exception {
        List<OutWorkerUpload> recs = new ArrayList<>();
        Worker worker = new Worker();
        List<WorkerBrandAccount> workerBrandAccount = new ArrayList<>();
        WorkerStreet workerStreet = new WorkerStreet();
        List<SignSplb> jySignSplbList = new ArrayList<>();
        List<SignSplb> sySignSplbList = new ArrayList<>();
        List<SignSplb> jyList = new ArrayList<>();
        List<SignSplb> syList = new ArrayList<>();
        WebsitQXLB websitqypl = new WebsitQXLB();
        List<ItfTblWangdianPositionDownload> wdwxgGl = new ArrayList<>();
        Map<String,List<ItfTblWangdianPositionDownload>> wdwxgGlMap = new HashMap<>();
        Map<String,List<Worker>> workersMap = new HashMap<>();

        String wxgaddapi = "/outapp/wxg/add";
        String wdqyapi = "/outapp/wxg/base";

        // 提取品牌信息
        Brand brand = baseService.getBrand();
        if (brand == null) {
            return;
        }

        wdwxgGl = itfTblWangdianPositionDownloadService.lambdaQuery().list();
        wdwxgGlMap = wdwxgGl.stream().
                collect(Collectors.groupingBy(ItfTblWangdianPositionDownload::getWxgno));

        // 只提取已入驻的师傅信息
        List<Worker> workers = workerService.lambdaQuery()
                .eq(Worker::getStatus,"ON").list();
        if (CollectionUtils.isNotEmpty(workers)){
            workersMap = workers.stream().
                    collect(Collectors.groupingBy(Worker::getWorkerId));
        }

        // 获取待同步数据
        recs = getWorkerUploads();

        for (OutWorkerUpload item:recs){
            try{
                WorkUploadInfo req = new WorkUploadInfo();
                WorkerCertificateInfo workerCertificateInfo = new WorkerCertificateInfo();

                // 获取师傅信息  需要同步的师傅必须在平台系统中存在
                if (!workersMap.containsKey(item.getWorkerId())){
                    // 写入表备注信息
                    updateWorkerUploadLag(item,"师傅尚未在平台中入驻");
                    continue;
                }
                worker = workersMap.get(item.getWorkerId()).get(0);

                // 查看师傅是否已选中品牌商 同步状态为有效状态
                // 这里存在一个商户网点对应平台多个网点
                workerBrandAccount = getWorkerBrandAccount(brand, item, worker);
                if (CollectionUtils.isEmpty(workerBrandAccount)) {
                    continue;
                }

                // 格力一个师傅最多三个有效网点超3个网点不能同步
                if (checkWebsitSum(workerBrandAccount,item)){
                    continue;
                }

                // 这里需要从对应的网点信息中提取师傅服务区域
                // 查看师傅服务区域 规定随便取一个地址即可
                workerStreet = getWorkerStreet(item, worker);
                if (workerStreet == null) {
                    continue;
                }

                // 验证师傅的保险证信息 所有网点都验证 这里只验证是否成功上传了图片
                if (checkBXOutInsureCert(workerBrandAccount)) {
                    continue;
                }

                // 按网点同步
                for (WorkerBrandAccount dot: workerBrandAccount){

                    // 提取师傅证件信息，未同步时不处理
                    if (getCertificateInfo(workerCertificateInfo, worker.getWorkerId(),dot.getWebsitWorkerId())){
                        break;
                    }

                    /**
                     * 必要条件必须满足，否则不进行数据上传动作 身份证、高空证、保险证
                     * 师傅信息同步到总部的必要条件：
                     * 1：身份证、2：保险，3：高空证(复审时间必填）  这三个条件必备否则无法同步
                     * 制冷证可以没有，如果填了复审时间则必填
                     */
                    if (checkNecessary(worker, item, workerCertificateInfo)){
                        break;
                    }

                    // 获取签约品类
                    if (getCategory(brand, jySignSplbList, sySignSplbList, worker, item, dot.getWorkerId())){
                        break;
                    }

                    // 生成数据对象 证件
                    getreq(workerCertificateInfo, req, worker,dot.getWebsitWorkerId());

                    // 师傅所在网点状态
                    req.setFlag("有效");
                    if (worker.getStatus().equals("OFF") || dot.getBrandWorkerStatus().equals("OFF")){
                        req.setFlag("无效");
                    }

                    //网点未签约品类时该网点师傅信息不同步
                    GreeResponseHelper response = getwdqylbxx(wdqyapi,dot.getBrandWebsitId());
                    if (response.getStatus() == 200){
                        // 获取网点签约的品类信息
                        websitqypl = JSONObject.parseObject(response.getData().toString(), WebsitQXLB.class);
                    } else {
                        // 写入表备注信息
                        updateWorkerUploadLag(item,"获取网点签约的品类信息失败["+
                                dot.getBrandWebsitId()+"]-"+
                                (StringUtils.isEmpty(response.getMsg()) ? "":response.getMsg()));
                        break;
                    }

                    // 从网点签约的品类信息中过滤师傅的品类信息
                    String result = extracted(jySignSplbList, sySignSplbList, jyList, syList, websitqypl,dot.getBrandWebsitId());
                    if (result.length()>0){
                        // 写入表备注信息
                        updateWorkerUploadLag(item,result);
                        continue;
                    }

                    // 过滤后无品类，不能上传
                    if (jyList.size()<1 && syList.size()<1){
                        // 写入表备注信息
                        updateWorkerUploadLag(item,"师傅签约品类过滤后不能同时为空");
                        continue;
                    }

                    // 按网点过滤师傅的类别信息
                    req.setJySignSplbList(jyList);
                    req.setSySignSplbList(syList);

                    // 服务人员编号(不填值为新增，填值为修改)
                    if (StringUtils.isNotEmpty(dot.getBrandWorkerNumber())){
                        req.setWxgno(dot.getBrandWorkerNumber());
                        // 重值部分数据 以格力门店数据为准
                        resetParameter(wdwxgGlMap, req,workerStreet);
                    } else {
                        extractedPCAS(req, workerStreet);
                    }
                    // 所属网点
                    req.setWdno(dot.getBrandWebsitId());

                    // 日志
                    log.info("报文：{}",JSONObject.toJSONString(req));

                    // 同步
                    syncData(dot.getId(), wxgaddapi, item, req,dot.getBrandWebsitId());

                    jyList.clear();
                    syList.clear();
                }
            } catch (Exception ex) {
                String msg ="同步失败";
                if (ex.getMessage() != null){
                    msg = ex.getMessage();
                }
                if (ex.getMessage() != null && ex.getMessage().trim().length() > 255) {
                    msg = ex.getMessage().substring(0, 255);
                }
                updateWorkerUploadLag(item,msg);
            }
        }
    }



    // 商户网点与平台网点存在一对多，确保正确，所有平台网点的图片都必须生成
    private boolean checkBXOutInsureCert(List<WorkerBrandAccount> workerBrandAccount) {
        List<String> websitworkerids = new ArrayList<>();
        workerBrandAccount.stream().forEach(wba->{
            websitworkerids.add(wba.getWebsitId());
        });
        List<WebsitWorker> websitWorkers = websitWorkerService.lambdaQuery()
                .in(WebsitWorker::getWebsitWorkerId,websitworkerids)
                .eq(WebsitWorker::getOutInsureCert,"").list();
        if (CollectionUtils.isNotEmpty(websitWorkers)){
            return true;
        }
        return false;
    }

    private void resetParameter(Map<String, List<ItfTblWangdianPositionDownload>> wdwxgGlMap,
                                WorkUploadInfo req,
                                WorkerStreet workerStreet) {
        if (wdwxgGlMap.containsKey(req.getWxgno())){
            ItfTblWangdianPositionDownload i = wdwxgGlMap.get(req.getWxgno()).get(0);
            req.setSfen(i.getSfen());
            req.setCshi(i.getCshi());
            req.setCounty(i.getCounty());
            req.setXzhen(i.getXzhen());
            req.setFlag(i.getFlag());
            req.setFwryzpfj(i.getFwryzpfj());
            req.setGzkkh(i.getGzkkh());
            req.setHmdbz(i.getHmdbz());
            req.setIfmessageFlag(i.getIfmessageFlag());
            req.setPxhgkssj(i.getPxhgkssj());
            req.setQbaoid(i.getQbaoid());
            req.setQbcheackFlag(i.getQbcheackFlag());
            req.setSfdswxgFlag(i.getSfdswxgFlag());
            req.setSfhmdFlag(i.getSfhmdFlag());
            req.setVipflag(i.getVipflag());
            req.setMaxaznum(i.getMaxaznum());
            req.setMaxwxnum(i.getMaxwxnum());
        } else {
            extractedPCAS(req, workerStreet);
        }
    }

    private String extracted(List<SignSplb> jySignSplbList, List<SignSplb> sySignSplbList,
                             List<SignSplb> jyList, List<SignSplb> syList, WebsitQXLB websitqypl,String brandWebsitNumber) {
        String result = "";
        List<String> syfwlbList = new ArrayList<>();
        List<String> jyfwlbList = new ArrayList<>();

        if (websitqypl.getJySignSplbList().size()<1 && websitqypl.getSySignSplbList().size()<1){
            result="网点【"+brandWebsitNumber+"】暂未签约品类";
            return result;
        }

        // 过滤商用品类
        if (websitqypl.getSySignSplbList().size()>0 && sySignSplbList.size()>0){
            // 大类名称 取交集
            websitqypl.getSySignSplbList().get(0).getFwlbList().retainAll(sySignSplbList.get(0).getFwlbList());
            syfwlbList.addAll(websitqypl.getSySignSplbList().get(0).getFwlbList());
            // 品类
            for (SignSplb sy : sySignSplbList){
                for (SignSplb wdsy: websitqypl.getSySignSplbList()){
                    if (wdsy.getSpdl().equals(sy.getSpdl())){
                        /*if (wdsy.getSpxl()==null){
                            result="网点:【"+brandWebsitNumber+"】商用大类【"+wdsy.getSpdl()+"】下未签约小类";
                            return result;
                        }*/
                        SignSplb one = new SignSplb();
                        one.setFwlbList(syfwlbList);
                        one.setSpdl(wdsy.getSpdl());
                        one.setSpdlName(wdsy.getSpdlName());
                        if (wdsy.getSpxl()!=null){
                            one.setSpxl(wdsy.getSpxl());
                            one.setSpxlName(wdsy.getSpxlName());
                        }
                        syList.add(one);
                    }
                }
            }
        }

        // 过滤家用品类
        if (websitqypl.getJySignSplbList().size()>0 && jySignSplbList.size()>0){
            // 大类名称 取交集
            websitqypl.getJySignSplbList().get(0).getFwlbList().retainAll(jySignSplbList.get(0).getFwlbList());
            jyfwlbList.addAll(websitqypl.getJySignSplbList().get(0).getFwlbList());
            // 品类
            for (SignSplb sy : jySignSplbList){
                for (SignSplb wdjy: websitqypl.getJySignSplbList()){
                    if (wdjy.getSpdl().equals(sy.getSpdl()) ){
                        /*if (wdjy.getSpxl()==null){
                            result="网点:【"+brandWebsitNumber+"】家用大类【"+wdjy.getSpdl()+"】下未签约小类";
                            return result;
                        }*/
                        SignSplb one = new SignSplb();
                        one.setFwlbList(jyfwlbList);
                        one.setSpdl(wdjy.getSpdl());
                        one.setSpdlName(wdjy.getSpdlName());
                        if (wdjy.getSpxl()==null){
                            one.setSpxl(wdjy.getSpxl());
                            one.setSpxlName(wdjy.getSpxlName());
                        }
                        jyList.add(one);
                    }
                }
            }
        }

        return result;
    }

    private Boolean checkNecessary(Worker worker, OutWorkerUpload item, WorkerCertificateInfo workerCertificateInfo) {
        if (StringUtils.isEmpty(workerCertificateInfo.getSfzbh())){
            updateWorkerUploadLag(item,"师傅缺失身份证信息，不上传");
            return Boolean.TRUE;
        }
        // 可不买保险 虚构保单
        if (StringUtils.isNotEmpty(workerCertificateInfo.getBxz()) && StringUtils.isEmpty(worker.getSafeNo())){
            worker.setSafeNo("99999999");
        }

        if (StringUtils.isEmpty(worker.getSafeNo()) || StringUtils.isEmpty(workerCertificateInfo.getBxz())){
            updateWorkerUploadLag(item,"师傅缺失保险信息，不上传");
            return Boolean.TRUE;
        }
        if (StringUtils.isEmpty(workerCertificateInfo.getGkzbh())){
            updateWorkerUploadLag(item,"师傅缺失高空证信息，不上传");
            return Boolean.TRUE;
        } else {
            if (StringUtils.isEmpty(workerCertificateInfo.getGkzfsrq())){
                updateWorkerUploadLag(item,"师傅高空证缺失证件复审时间:，不上传");
                return Boolean.TRUE;
            }
        }
        if (StringUtils.isNotEmpty(workerCertificateInfo.getZlgbh())){
            if (StringUtils.isEmpty(workerCertificateInfo.getZlgfsrq())){
                updateWorkerUploadLag(item,"师傅制冷证缺失证件复审时间:，不上传");
                return Boolean.TRUE;
            }
        }

        return Boolean.FALSE;
    }

    private Boolean getCertificateInfo(WorkerCertificateInfo workerCertificateInfo, String workerId, String websitWorkerId) throws ParseException {
        // 身份证
        if (getsfz(workerCertificateInfo, workerId)){
            return Boolean.FALSE;
        }
        // 保险证
        if (getbxz(workerCertificateInfo, workerId, websitWorkerId)){
            return Boolean.FALSE;
        }
        // 高空作业证
        if (getgkz(workerCertificateInfo, workerId)){
            return Boolean.FALSE;
        }
        // 上岗资格证
        if (getsgz(workerCertificateInfo, workerId)){
            return Boolean.TRUE;
        }
        // 制冷工证
        if (getzlz(workerCertificateInfo, workerId)){
            return Boolean.TRUE;
        }
        // 驾驶证
        if (getjsz(workerCertificateInfo, workerId)){
            return Boolean.TRUE;
        }

        return Boolean.FALSE;
    }

    private Boolean getCertificateInfoWorkerCert(WorkerCertificateInfo workerCertificateInfo, String workerId) throws ParseException {
        // 提取身份证信息 无不同步
        if (getsfz(workerCertificateInfo, workerId)){
            return Boolean.TRUE;
        }

        // 高空作业证
        if (getgkz(workerCertificateInfo, workerId)){
            return Boolean.TRUE;
        }

        return Boolean.FALSE;
    }

    // true为有信息
    private Boolean getjsz(WorkerCertificateInfo workerCertificateInfo, String workerId) throws ParseException {
        WorkerCert certificate = getCertificateInfo(workerId,"驾驶证");
        // 无证件不处理
        if (certificate == null){
            return Boolean.FALSE;
        }
        // 身份证信息未同步，不操作
        if (!certificate.getOutSyncStatus().equals(1)){
            return Boolean.TRUE;
        }
        if (StringUtils.isNotEmpty(certificate.getOutFileUrl())){
            workerCertificateInfo.setJszz(certificate.getOutFileUrl());
        }
        if (StringUtils.isNotEmpty(certificate.getOutFileUrl2())){
            workerCertificateInfo.setJszf(certificate.getOutFileUrl2());
        }

        if (certificate.getExpireTime() !=null){
            workerCertificateInfo.setJszyxq(datesub(certificate.getExpireTime()));
        }
        if (certificate.getReviewTime() !=null){
            workerCertificateInfo.setJszfsrq(datesub(certificate.getReviewTime()));
        }

        return Boolean.FALSE;
    }

    // true为有信息
    private Boolean getzlz(WorkerCertificateInfo workerCertificateInfo, String workerId) throws ParseException {
        WorkerCert certificate = getCertificateInfo(workerId,"制冷证");
        // 无证件不处理
        if (certificate == null){
            return Boolean.FALSE;
        }
        // 身份证信息未同步，不操作
        if (!certificate.getOutSyncStatus().equals(1)){
            return Boolean.TRUE;
        }
        if (StringUtils.isNotEmpty(certificate.getOutFileUrl())){
            workerCertificateInfo.setZlgz(certificate.getOutFileUrl());
        }
        if (StringUtils.isNotEmpty(certificate.getOutFileUrl2())){
            workerCertificateInfo.setZlgf(certificate.getOutFileUrl2());
        }
        workerCertificateInfo.setZlgbh(certificate.getCertNo());

        if (certificate.getExpireTime() !=null){
            workerCertificateInfo.setZlgyxq(datesub(certificate.getExpireTime()));
        }
        if (certificate.getReviewTime() !=null){
            workerCertificateInfo.setZlgfsrq(datesub(certificate.getReviewTime()));
        }

        return Boolean.FALSE;
    }

    // true为有证件
    private Boolean getsgz(WorkerCertificateInfo workerCertificateInfo, String workerId) throws ParseException {
        WorkerCert certificate = getCertificateInfo(workerId,"上岗证");
        // 无证件不处理
        if (certificate == null){
            return Boolean.FALSE;
        }
        // 身份证信息未同步，不操作
        if (!certificate.getOutSyncStatus().equals(1)){
            return Boolean.TRUE;
        }
        if (StringUtils.isNotEmpty(certificate.getOutFileUrl())){
            workerCertificateInfo.setSgzgzz(certificate.getOutFileUrl());
        }
        if (StringUtils.isNotEmpty(certificate.getOutFileUrl2())){
            workerCertificateInfo.setSgzgzf(certificate.getOutFileUrl2());
        }
        workerCertificateInfo.setSgzgzbh(certificate.getCertNo());

        if (certificate.getExpireTime() !=null){
            workerCertificateInfo.setSgzgzyxq(datesub(certificate.getExpireTime()));
        }
        if (certificate.getReviewTime() !=null){
            workerCertificateInfo.setSgzgzfsrq(datesub(certificate.getReviewTime()));
        }

        return Boolean.FALSE;
    }

    // true为有信息
    private Boolean getgkz(WorkerCertificateInfo workerCertificateInfo, String workerId) throws ParseException {
        WorkerCert certificate = getCertificateInfo(workerId,"高空证");
        // 无证件不处理
        if (certificate == null){
            return Boolean.TRUE;
        }
        // 身份证信息未同步，不操作
        if (!certificate.getOutSyncStatus().equals(1)){
            return Boolean.TRUE;
        }
        if (StringUtils.isNotEmpty(certificate.getOutFileUrl())){
            workerCertificateInfo.setGkzz(certificate.getOutFileUrl());
        }
        if (StringUtils.isNotEmpty(certificate.getOutFileUrl2())){
            workerCertificateInfo.setGkzf(certificate.getOutFileUrl2());
        }
        workerCertificateInfo.setGkzbh(certificate.getCertNo());

        if (certificate.getExpireTime() !=null){
            workerCertificateInfo.setGkzyxq(datesub(certificate.getExpireTime()));
        }
        if (certificate.getReviewTime() !=null){
            workerCertificateInfo.setGkzfsrq(datesub(certificate.getReviewTime()));
        }

        return Boolean.FALSE;
    }

    // true为有信息
    private Boolean getbxz(WorkerCertificateInfo workerCertificateInfo, String workerId, String websitWorkerId) throws ParseException {
        WebsitWorker wk = websitWorkerService.lambdaQuery()
                .eq(WebsitWorker::getWebsitWorkerId,websitWorkerId)
                .last("limit 1")
                .one();

        // 证件信息未同步，不操作
        if (StringUtils.isEmpty(wk.getOutInsureCert())){
            return Boolean.TRUE;
        }
        workerCertificateInfo.setBxz(wk.getOutInsureCert());
        if (wk.getGmbxyxq() !=null){
            workerCertificateInfo.setBxyxq(datesub(wk.getGmbxyxq()));
        }

        return Boolean.FALSE;
    }

    private Boolean getbxzBak(WorkerCertificateInfo workerCertificateInfo, String workerId) throws ParseException {
        WorkerCert certificate = getCertificateInfo(workerId,"保险证");
        // 无证件不处理
        if (certificate == null){
            return Boolean.TRUE;
        }
        // 身份证信息未同步，不操作
        if (!certificate.getOutSyncStatus().equals(1)){
            return Boolean.TRUE;
        }
        if (StringUtils.isNotEmpty(certificate.getOutFileUrl())){
            workerCertificateInfo.setBxz(certificate.getOutFileUrl());
        }
        if (StringUtils.isNotEmpty(certificate.getOutFileUrl2())){
            workerCertificateInfo.setBxf(certificate.getOutFileUrl2());
        }

        if (certificate.getExpireTime() !=null){
            workerCertificateInfo.setBxyxq(datesub(certificate.getExpireTime()));
        }
        if (certificate.getReviewTime() !=null){
            workerCertificateInfo.setBxfsrq(datesub(certificate.getReviewTime()));
        }

        return Boolean.FALSE;
    }

    private Boolean getsfz(WorkerCertificateInfo workerCertificateInfo, String workerId) throws ParseException {
        WorkerCert certificate = getCertificateInfo(workerId,"身份证");
        // 无证件不处理
        if (certificate == null){
            return Boolean.TRUE;
        }
        // 身份证信息未同步，不操作
        if (!certificate.getOutSyncStatus().equals(1)){
            return Boolean.TRUE;
        }
        if (StringUtils.isNotEmpty(certificate.getOutFileUrl())){
            workerCertificateInfo.setSfzz(certificate.getOutFileUrl());
        }
        if (StringUtils.isNotEmpty(certificate.getOutFileUrl2())){
            workerCertificateInfo.setSfzf(certificate.getOutFileUrl2());
        }
        workerCertificateInfo.setSfzbh(certificate.getCertNo());

        if (certificate.getExpireTime() !=null){
            workerCertificateInfo.setSfzyxq(datesub(certificate.getExpireTime()));
        }
        if (certificate.getReviewTime() !=null){
            workerCertificateInfo.setSfzfsrq(datesub(certificate.getReviewTime()));
        }

        return Boolean.FALSE;
    }

    public String datesub(@NotNull Date d) {
        SimpleDateFormat sf = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss'Z'", Locale.US);
        long localTime = d.getTime()-8*60*60*1000;
        Calendar calendar = Calendar.getInstance();
        calendar.setTimeInMillis(localTime);
        Date utcDate = new Date(calendar.getTimeInMillis());
        return sf.format(utcDate);
    }

    public String dateToUTC(Date d) throws ParseException {
        SimpleDateFormat sdft = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String format = "yyyy/MM/dd HH:mm:ss";
        SimpleDateFormat sf = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss'Z'", Locale.US);
        SimpleDateFormat sdf = new SimpleDateFormat (format);
        sdf.setTimeZone(TimeZone.getTimeZone("UTC"));
        Date gmtTime = new Date(sdf.format(d));
        return sf.format(gmtTime);
    }

    private WorkerCert getCertificateInfo(String workerId, String certName){
        List<WorkerCert> recs = new ArrayList<>();
        recs = workerCertService.lambdaQuery()
                .eq(WorkerCert::getWorkerId, workerId)
                .eq(WorkerCert::getCertName, certName)
                .list();

        // 无证件不处理
        if (recs.size()<1){
            return null;
        }
        return recs.get(0);
    }

    // 获取网点签约的品类信息 并过滤师傅的品类信息
    private GreeResponseHelper getwdqylbxx(String apiPath, String wdno) throws Exception {
        Map<String,String> req = new HashMap<>();

        req.put("wdno",wdno);
        GreeResponseHelper response = greeLogic.greePost(apiPath, JSONObject.toJSONString(req), publicService.getCompanyId(wdno));
        return response;
    }

    private void syncData(String id, String apiPath, OutWorkerUpload item, WorkUploadInfo req,String brandWebsitId) throws Exception {
        GreeResponseHelper response = greeLogic.greePost(apiPath, JSONObject.toJSONString(req), publicService.getCompanyId(brandWebsitId));

        if (response.getStatus() == 200){
            // 成功 修改同步状态
            updateWorkerUploadSuccess(item);
            // 修改师傅品牌网点帐号
            updataWorker(id, response);
        } else {
            // 失败 修改同步状态
            updateWorkerUploadError(item, response);
        }
    }

    private void updateWorkerUploadError(OutWorkerUpload item, GreeResponseHelper response) {
        OutWorkerUpload v = new OutWorkerUpload();
        v.setSynReqId(item.getSynReqId());
        v.setSyncStatus(99);
        v.setSyncTime(new Date());
        v.setSyncTimes(item.getSyncTimes()+1);

        if (response.getMsg().length()>255){
            v.setSyncErrorMsg(response.getMsg().substring(0,255));
        } else {
            v.setSyncErrorMsg(response.getMsg());
        }

        outWorkerUploadService.updateById(v);
    }

    // 这里只有修改
    private void updataWorker(String id, GreeResponseHelper response) {
        WorkerBrandAccount w = new WorkerBrandAccount();
        w.setId(id);
        w.setOutSyncTime(new Date());
        WorkerUploadResponse resultData = JSONObject.parseObject(response.getData().toString(), WorkerUploadResponse.class);
        w.setBrandWorkerNumber(resultData.getWxgno());
        w.setBrandWorkerId(String.valueOf(resultData.getId()));
        workerBrandAccountService.updateById(w);
    }

    private void updateWorkerUploadSuccess(OutWorkerUpload item) {
        OutWorkerUpload v = new OutWorkerUpload();
        v.setSynReqId(item.getSynReqId());
        v.setSyncStatus(1);
        v.setSyncTime(new Date());
        v.setSyncTimes(item.getSyncTimes()+1);
        v.setSyncErrorMsg("成功");
        outWorkerUploadService.updateById(v);
    }

    private void getreq(WorkerCertificateInfo workerCertificateInfo, WorkUploadInfo req, Worker worker,String websitWorkerId) throws Exception {
        List<ZJInfo> zjInfoList = new ArrayList<>();

        // 证件信息
        getcert(workerCertificateInfo, zjInfoList, worker, websitWorkerId);

        // 生成数据对象
        setReq(zjInfoList, req, worker,websitWorkerId);
    }

    private Boolean extractedPCAS(WorkUploadInfo req, WorkerStreet workerStreet) {
        req.setSfen(workerStreet.getProvince());
        req.setCshi(workerStreet.getCity());
        req.setCounty(workerStreet.getArea());
        req.setXzhen(workerStreet.getStreet());
        return Boolean.TRUE;
    }

    private void setReq(List<ZJInfo> zjInfoList, WorkUploadInfo req, Worker worker, String websitWorkerId) {
        WebsitWorker wb = websitWorkerService.lambdaQuery()
                .eq(WebsitWorker::getWebsitWorkerId,websitWorkerId)
                .last("limit 1")
                .one();
        req.setZjInfoList(zjInfoList);

        req.setCsgzns(worker.getJobAge());
        // 必填
        req.setDizhi(worker.getAddress());
        req.setFacecheck(wb.getFaceCheck());
        req.setFacepath("");
        if (StringUtils.isNotEmpty(wb.getFacePath())){
            req.setFacepath(wb.getFacePath());
        }

        // 必填
        req.setFwryzpfj("www");
        if (StringUtils.isNotEmpty(worker.getImgUrl())){
            req.setFwryzpfj(worker.getImgUrl());
        }
        req.setGzkkh("");
        if (StringUtils.isNotEmpty(worker.getBankAccount())){
            req.setGzkkh(worker.getBankAccount());
        }
        req.setGzkssyh("");
        if (StringUtils.isNotEmpty(worker.getBankDeposit())){
            req.setGzkssyh(worker.getBankDeposit());
        }
        req.setHasfaceFlag(Boolean.FALSE);
        if (wb.getHasFace()==1){
            req.setHasfaceFlag(Boolean.TRUE);
        }
        req.setHmdbz("");
        if (StringUtils.isNotEmpty(worker.getBlackListRemark())){
            req.setHmdbz(worker.getBlackListRemark());
        }
        // 必填
        req.setIfmessageFlag(Boolean.FALSE);
        if (worker.getIsSmsNotice().equals("YES")){
            req.setIfmessageFlag(Boolean.TRUE);
        }
        req.setNianl(worker.getAge());
        req.setPxhgkssj("");
        /*if (worker.getTrainPassTime() !=null ){
            req.setPxhgkssj(datesub(worker.getTrainPassTime()));
        }*/
        req.setQbaoid("");
        req.setQbcheackFlag(Boolean.FALSE);
        req.setSfdswxgFlag(Boolean.FALSE);

        // 必填
        req.setSfhmdFlag(Boolean.FALSE);
        if (worker.getIsBlackList().equals("YES")){
            req.setSfhmdFlag(Boolean.TRUE);
        }
        req.setSfpxhgFlag(Boolean.TRUE);
        /*if (worker.getTrainStatus()){
            req.setSfpxhgFlag(Boolean.TRUE);
        }*/
        // 必填
        req.setSfzstFlag(Boolean.FALSE);
        if (worker.getIsZst().equals("YES")){
            req.setSfzstFlag(Boolean.TRUE);
        }
        req.setVipflag(worker.getVipFlag());

        req.setWxfensu(wb.getScore());
        // 必填
        req.setWxgmc(worker.getWorkerName());
        req.setXcsgz("");
        if (StringUtils.isNotEmpty(worker.getJob())){
            req.setXcsgz(worker.getJob());
        }
        // 必填
        req.setXingb(worker.getGender());

        // 必填 必须初中以下
        req.setXueli("中专");
        if (StringUtils.isNotEmpty(worker.getEducation())){
            req.setXueli(worker.getEducation());
        }
        // 必填
        if (StringUtils.isNotEmpty(worker.getMobile())){
            req.setYddh(worker.getMobile());
        }
        req.setMaxwxnum(wb.getRepairDayLimit());
        req.setMaxaznum(wb.getInstallDayLimit());
    }

    private void getcert(WorkerCertificateInfo workerCertificateInfo,
                         List<ZJInfo> zjInfoList, Worker worker,String websitWorkerId) throws Exception {
        // 身份证  必要条件
        if (StringUtils.isNotEmpty(workerCertificateInfo.getSfzbh())) {
            ZJInfo zjInfo = new ZJInfo();
            zjInfo.setZjbh(workerCertificateInfo.getSfzbh());
            zjInfo.setZjmc("身份证");
            zjInfo.setZjyxq("");

            // 证件路径 必填
            if (StringUtils.isNotEmpty(workerCertificateInfo.getSfzz())) {
                zjInfo.setZjlj(workerCertificateInfo.getSfzz());
            }
            if (StringUtils.isNotEmpty(workerCertificateInfo.getSfzf())) {
                if (StringUtils.isNotEmpty(workerCertificateInfo.getSfzz())) {
                    zjInfo.setZjlj(zjInfo.getZjlj() + "," + workerCertificateInfo.getSfzf());
                } else {
                    zjInfo.setZjlj(workerCertificateInfo.getSfzf());
                }

            }
            if (StringUtils.isNotEmpty(workerCertificateInfo.getSfzyxq())) {
                zjInfo.setZjyxq(workerCertificateInfo.getSfzyxq());
            }
            if (StringUtils.isNotEmpty(workerCertificateInfo.getSfzfsrq())) {
                zjInfo.setZjfssj(workerCertificateInfo.getSfzfsrq());
            }

            zjInfoList.add(zjInfo);
        }

        // 保险  必要条件
        if (StringUtils.isNotEmpty(worker.getSafeNo())){
            ZJInfo zjInfo = new ZJInfo();
            WebsitWorker ww = new WebsitWorker();
            ww = websitWorkerService.lambdaQuery()
                    .eq(WebsitWorker::getWebsitWorkerId,websitWorkerId)
                    .last("limit 1")
                    .one();

            zjInfo.setZjbh(ww.getSafeCompany()+"/"+ ww.getSafeNo());
            zjInfo.setZjmc("保险证");

            // 证件路径 必填
            if (StringUtils.isNotEmpty(workerCertificateInfo.getBxz())) {
                zjInfo.setZjlj(workerCertificateInfo.getBxz());
            }
            if (StringUtils.isNotEmpty(workerCertificateInfo.getBxf())) {
                if (StringUtils.isNotEmpty(workerCertificateInfo.getBxz())) {
                    zjInfo.setZjlj(zjInfo.getZjlj() + "," + workerCertificateInfo.getBxf());
                } else {
                    zjInfo.setZjlj(workerCertificateInfo.getBxf());
                }
            }

            if (StringUtils.isNotEmpty(workerCertificateInfo.getBxyxq())) {
                zjInfo.setZjyxq(workerCertificateInfo.getBxyxq());
            }
            if (StringUtils.isNotEmpty(workerCertificateInfo.getBxfsrq())) {
                zjInfo.setZjfssj(workerCertificateInfo.getBxfsrq());
            }

            zjInfoList.add(zjInfo);
        }

        // 高空作业证  必要条件
        if (StringUtils.isNotEmpty(workerCertificateInfo.getGkzbh())
                && StringUtils.isNotEmpty(workerCertificateInfo.getGkzyxq())){
            ZJInfo zjInfo = new ZJInfo();
            zjInfo.setZjbh(workerCertificateInfo.getGkzbh());
            zjInfo.setZjmc("高空作业证");
            zjInfo.setZjfssj(workerCertificateInfo.getGkzfsrq());

            // 证件路径 必填
            if (StringUtils.isNotEmpty(workerCertificateInfo.getGkzz())) {
                zjInfo.setZjlj(workerCertificateInfo.getGkzz());
            }
            if (StringUtils.isNotEmpty(workerCertificateInfo.getGkzf())) {
                if (StringUtils.isNotEmpty(workerCertificateInfo.getGkzz())) {
                    zjInfo.setZjlj(zjInfo.getZjlj() + "," + workerCertificateInfo.getGkzf());
                } else {
                    zjInfo.setZjlj(workerCertificateInfo.getGkzf());
                }
            }

            zjInfo.setZjfssj(workerCertificateInfo.getGkzfsrq());
            zjInfo.setZjyxq(workerCertificateInfo.getGkzyxq());
            zjInfoList.add(zjInfo);
        }

        // 上岗资格证
        if (StringUtils.isNotEmpty(workerCertificateInfo.getSgzgzbh())){
            ZJInfo zjInfo = new ZJInfo();
            zjInfo.setZjbh(workerCertificateInfo.getSgzgzbh());
            zjInfo.setZjmc("上岗资格证");

            // 证件路径 必填
            if (StringUtils.isNotEmpty(workerCertificateInfo.getSgzgzz())) {
                zjInfo.setZjlj(workerCertificateInfo.getSgzgzz());
            }
            if (StringUtils.isNotEmpty(workerCertificateInfo.getSgzgzf())) {
                if (StringUtils.isNotEmpty(workerCertificateInfo.getSgzgzz())) {
                    zjInfo.setZjlj(zjInfo.getZjlj() + "," + workerCertificateInfo.getSgzgzf());
                } else {
                    zjInfo.setZjlj(workerCertificateInfo.getSgzgzf());
                }
            }

            zjInfo.setZjfssj(workerCertificateInfo.getSgzgzfsrq());
            zjInfo.setZjyxq(workerCertificateInfo.getSgzgzyxq());

            zjInfoList.add(zjInfo);
        }

        // 制冷工证
        if (StringUtils.isNotEmpty(workerCertificateInfo.getZlgbh())){
            ZJInfo zjInfo = new ZJInfo();
            zjInfo.setZjbh(workerCertificateInfo.getZlgbh());
            zjInfo.setZjmc("制冷工证");

            // 证件路径 必填
            if (StringUtils.isNotEmpty(workerCertificateInfo.getZlgz())) {
                zjInfo.setZjlj(workerCertificateInfo.getZlgz());
            }
            if (StringUtils.isNotEmpty(workerCertificateInfo.getZlgf())) {
                if (StringUtils.isNotEmpty(workerCertificateInfo.getZlgz())) {
                    zjInfo.setZjlj(zjInfo.getZjlj() + "," + workerCertificateInfo.getZlgf());
                } else {
                    zjInfo.setZjlj(workerCertificateInfo.getZlgf());
                }
            }

            zjInfo.setZjfssj(workerCertificateInfo.getZlgfsrq());
            zjInfo.setZjyxq(workerCertificateInfo.getZlgyxq());

            zjInfoList.add(zjInfo);
        }

        // 驾驶证
        if (StringUtils.isNotEmpty(workerCertificateInfo.getCph())){
            ZJInfo zjInfo = new ZJInfo();
            zjInfo.setZjbh(workerCertificateInfo.getCph());
            zjInfo.setZjmc("驾驶证");

            if (StringUtils.isNotEmpty(worker.getGpsMachineId())){
                zjInfo.setZjbh(workerCertificateInfo.getCph()+"/"+ worker.getGpsMachineId());
            }

            // 证件路径 必填
            if (StringUtils.isNotEmpty(workerCertificateInfo.getJszz())) {
                zjInfo.setZjlj(workerCertificateInfo.getJszz());
            }
            if (StringUtils.isNotEmpty(workerCertificateInfo.getJszf())) {
                if (StringUtils.isNotEmpty(workerCertificateInfo.getJszz())) {
                    zjInfo.setZjlj(zjInfo.getZjlj() + "," + workerCertificateInfo.getJszf());
                } else {
                    zjInfo.setZjlj(workerCertificateInfo.getJszf());
                }
            }

            zjInfo.setZjfssj(workerCertificateInfo.getJszfsrq());
            zjInfo.setZjyxq(workerCertificateInfo.getJszyxq());

            zjInfoList.add(zjInfo);
        }
    }

    /**
     * 签约大类，必须有对应的小类信息，否则无法上传(获取所有的大类对应的小类信息，再从网点本身过滤掉)
     */
    private Boolean getCategory(Brand brand, List<SignSplb> jySignSplbList, List<SignSplb> sySignSplbList,
                                Worker worker, OutWorkerUpload itemi, String workerId) {
        List<String> SYDictDaleiCode = new ArrayList<>();

        // 提取品牌商所有的商用大类信息
        List<SysDict> sysDicts = sysDictService.lambdaQuery()
                .eq(SysDict::getDictType, DictTypeEnum.DICT_TYPE_MAIN_TYPE.getCode())
                .eq(SysDict::getFlag, DictTypeEnum.DICT_TYPE_FLAG_SY.getCode()).list();
        if (sysDicts !=null && sysDicts.size()>0){
            SYDictDaleiCode = sysDicts.stream().map(SysDict::getDictCode).collect(Collectors.toList());
        }

        // 提取师傅的服务大类信息
        List<WorkerServiceCategoryDetail> wxgCategoryRecs = workerServiceCategoryDetailService.lambdaQuery()
                .eq(WorkerServiceCategoryDetail::getWorkerId, worker.getWorkerId())
                .eq(WorkerServiceCategoryDetail::getWebsitId, workerId).list();

        // 组装类别参数
        if (wxgCategoryRecs !=null && wxgCategoryRecs.size()>0){
            getCategoryt(brand, jySignSplbList, sySignSplbList, SYDictDaleiCode, wxgCategoryRecs);
        }

        if (jySignSplbList.size()<1 && sySignSplbList.size()<1){
            // 写入表备注信息
            updateWorkerUploadLag(itemi,"师傅签约的品类不能同时为空");
            return Boolean.TRUE;
        }

        return Boolean.FALSE;
    }

    // 获取类别信息
    // 师傅的服务类型分，安装、维修、配送等
    // 格力网点答约的服务类目也要限制师傅的品数参数
    private void getCategoryt(Brand brand, List<SignSplb> jySignSplbList, List<SignSplb> sySignSplbList,
                              List<String> SYDictDaleiCode, List<WorkerServiceCategoryDetail> wxgCategoryRecs) {
        List<SysDictRef> sysDictRefs = new ArrayList<>();

        // 组装参数类别名称信息
        List<String> fwlbList = getCategoryName(wxgCategoryRecs);

        // 获取师傅在品牌商品对应的类别信息
        getDictRefs(brand, wxgCategoryRecs, sysDictRefs);

        // 组装品类参数
        for (SysDictRef item:sysDictRefs){
            // 大类对应的小类必填
            // 获取品牌商的大类对应的所有小类信息
            List<SysDict> categorys = sysDictService.lambdaQuery()
                    .eq(SysDict::getDictType, DictTypeEnum.DICT_TYPE_SMALL_TYPE.getCode())
                    .eq(SysDict::getParentDictType, DictTypeEnum.DICT_TYPE_MAIN_TYPE.getCode())
                    .eq(SysDict::getStatus, DictTypeEnum.DICT_TYPE_ON.getCode())
                    // .eq(SysDict::getDictCode, "120300") 测试用
                    .eq(SysDict::getParentDictCode, item.getRefDictCode()).list();
            if (categorys !=null && categorys.size()>0){
                for (SysDict category :categorys){
                    SignSplb v = new SignSplb();
                    v.setSpdl(Integer.valueOf(item.getRefDictCode()));
                    v.setSpdlName(item.getRefDictName());
                    v.setSpxl(Integer.valueOf(category.getDictCode()));
                    v.setSpxlName(category.getDictValue());
                    v.setFwlbList(fwlbList);
                    // 查看是否为商用
                    if (SYDictDaleiCode.contains(item.getDictCode())){
                        sySignSplbList.add(v);
                    } else {
                        jySignSplbList.add(v);
                    }
                }
            }
        }
    }

    @NotNull
    private List<String> getCategoryName(List<WorkerServiceCategoryDetail> wxgCategoryRecs) {
        // 服务类型 INSTALL=安装 REPAIR=维修  DELIVERY=配送
        Map<String,String> serviceFwlbList = new HashMap<>();
        for (WorkerServiceCategoryDetail w: wxgCategoryRecs){
            if (w.getType().equals("INSTALL")){
                serviceFwlbList.put("INSTALL","安装");
            } else if (w.getType().equals("REPAIR")){
                serviceFwlbList.put("REPAIR\"","维修");
            } else if (w.getType().equals("DELIVERY")){
                serviceFwlbList.put("DELIVERY","配送");
            }
        }
        List<String> fwlbList = new ArrayList<>();
        Set<String> keySet = serviceFwlbList.keySet();
        for (String key : keySet){
            String val = serviceFwlbList.get(key);
            fwlbList.add(val);
        }
        return fwlbList;
    }

    private void getDictRefs(Brand brand, List<WorkerServiceCategoryDetail> wxgCategoryRecs, List<SysDictRef> sysDictRefs) {
        List<String> wxgCaregoryIds = wxgCategoryRecs.stream().map(WorkerServiceCategoryDetail::getMainId).collect(Collectors.toList());

        // 提取师傅所在品牌商对应的大类信息
        List<SysDictRef> sysDictRefRecs =  sysDictRefService.lambdaQuery()
                .eq(SysDictRef::getBrandId, brand.getBrandId())
                .eq(SysDictRef::getDictType, DictTypeEnum.DICT_TYPE_MAIN_TYPE.getCode())
                .in(SysDictRef::getDictCode,wxgCaregoryIds).list();

        // sysDictRefs 内的大类信息需去除无效的大类信息
        // 提取品牌商所有无效的大类信息
        List<SysDict> daleis = sysDictService.lambdaQuery()
                .eq(SysDict::getDictType, DictTypeEnum.DICT_TYPE_MAIN_TYPE.getCode())
                .eq(SysDict::getStatus, DictTypeEnum.DICT_TYPE_OFF.getCode())
                .list();
        if ((daleis !=null && daleis.size()>0) && (sysDictRefRecs!=null && sysDictRefRecs.size()>0)){
            List<String> daleiCodes = new ArrayList<>();
            daleiCodes = daleis.stream().map(SysDict::getDictCode).collect(Collectors.toList());
            for (SysDictRef s: sysDictRefRecs){
                if (!daleiCodes.contains(s.getDictCode())){
                    sysDictRefs.add(s);
                }
            }
        } else {
            sysDictRefs.addAll(sysDictRefRecs);
        }

    }


    @Nullable
    private WorkerStreet getWorkerStreet(OutWorkerUpload item, Worker worker) {
        List<WorkerStreet> wss = workerStreetService.lambdaQuery()
                .eq(WorkerStreet::getWorkerId, worker.getWorkerId()).list();
        if (wss == null || wss.size()<1){
            // 写入表备注信息
            updateWorkerUploadLag(item,"师傅服务区域信息不存在");
            return null;
        }
        WorkerStreet ws = wss.get(0);
        // 必填参数 省份-城市-区县-乡镇
        /*if (StringUtils.isEmpty(ws.getProvince()) || StringUtils.isEmpty(ws.getCity())
        || StringUtils.isEmpty(ws.getArea()) || StringUtils.isEmpty(ws.getStreet())){
            updateWorkerUploadLag(item,"师傅所在省市区镇信息缺失");
            return null;
        }
*/
        return ws;
    }

    private void updateWorkerUploadLag(OutWorkerUpload item, String msg) {
        OutWorkerUpload v = new OutWorkerUpload();
        v.setSynReqId(item.getSynReqId());
        v.setSyncTime(new Date());
        v.setSyncErrorMsg(msg);
        if (msg.length()>255){
            v.setSyncErrorMsg(msg.substring(0,255));
        }
        outWorkerUploadService.updateById(v);
    }

    @Nullable
    private List<WorkerBrandAccount> getWorkerBrandAccount(Brand brand, OutWorkerUpload item, Worker worker) {
        List<WorkerBrandAccount> workerBrandAccount = workerBrandAccountService.lambdaQuery()
                .eq(WorkerBrandAccount::getWorkerId, worker.getWorkerId())
                .eq(WorkerBrandAccount::getGroupCompanyId, brand.getBrandId())
                .eq(WorkerBrandAccount::getBrandWorkerStatus,"ON")
                .eq(WorkerBrandAccount::getDel, 0)
                .orderByAsc(WorkerBrandAccount::getCreateTime)
                .list();

        if (CollectionUtils.isEmpty(workerBrandAccount)){
            // 写入表备注信息
            updateWorkerUploadLag(item,"师傅未选择品牌商");
            return null;
        }
        return workerBrandAccount;
    }


    private Boolean checkWebsitSum(List<WorkerBrandAccount> workerBrandAccount, OutWorkerUpload item){
        // 格力一个师傅最多三个有效网点超3个网点不能同步
        Integer sum = 0;
        for (WorkerBrandAccount wba :workerBrandAccount){
            if (wba.getBrandWorkerStatus().equals("ON")){
                sum ++;
            }
        }
        if (sum>3) {
            // 写入表备注信息
            updateWorkerUploadLag(item,"师傅所在有效网点数超过3个无法同步");
            return Boolean.TRUE;
        }

        return Boolean.FALSE;
    }


    @Nullable
    private Worker getWorker(OutWorkerUpload item) {
        Worker worker = workerService.lambdaQuery()
                .eq(Worker::getWorkerId, item.getWorkerId())
                .eq(Worker::getStatus,"ON").one();
        if (worker ==null){
            return null;
        }
        return worker;
    }

    private List<OutWorkerUpload> getWorkerUploads() {
        // 同步标志-synStatus(0:待同步;1:已同步;99:同步失败)
        List<OutWorkerUpload> recs;
        LambdaQueryWrapper<OutWorkerUpload> queryWrapper = new LambdaQueryWrapper<OutWorkerUpload>()
                .eq(OutWorkerUpload::getSyncStatus,0)
                .or(wrapper->wrapper.eq(OutWorkerUpload::getSyncStatus,99)
                        .le(OutWorkerUpload::getSyncTimes,10));
        recs = outWorkerUploadService.list(queryWrapper);
        return recs;
    }
}
